@@ -37,6 +37,8 @@ class SQLConnector(Connector, ABC):
     method. They inherit the public API for end-users.
     '''
 
+    SAMPLE_SIZE = 10
+
     # --- Abstract interface ----------------------------------------------------------------------
 
     @abstractmethod
@@ -48,9 +50,13 @@ class SQLConnector(Connector, ABC):
         '''Returns a list with the resources scoped to the given parents.'''
 
     @abstractmethod
-    def suggest_schema(self, parents):
+    def suggest_schema(self, scopes):
         '''Returns a ClickHouse schema for the given table.'''
 
+    # @abstractmethod
+    # def ingest_query(self, schema, column_names):
+    #     '''Returns the SQL query to be executed for data ingestion.'''
+
     @abstractmethod
     def _export(self, query, fmt):
         '''Export the given query, and return an export object.'''
@@ -59,6 +65,14 @@ class SQLConnector(Connector, ABC):
     def _query(self, sql):
         '''Execute a query against the database and return the result set as list of dictionaries.'''
 
+    #
+    # --- Sample ----------------------------------------------------------------------------------
+    #
+
+    def sample(self, schema, column_names):
+        query = self.ingest_query(schema, column_names)
+        return self.query_db(f'{query} LIMIT {self.SAMPLE_SIZE}')
+
     # --- Query this connector's database ---------------------------------------------------------
 
     def query_db(self, sql, scalar=False):
