@@ -136,16 +136,36 @@ class Connector(connector.SQLConnector):
     #
 
     def ingest_query(self, schema, column_names):
-        # projections = []
-        # for column in schema.columns:
-        #     if column.name in column_names:
-        #         quoted = f'`{column.name}`'
-        #         if column.src_type.name.startswith('ARRAY'):
-        #             projections.append(f'TO_JSON({quoted})')
-        #         else:
-        #             projections.append(quoted)
-        # return 'SELECT ' + ', '.join(projections) + ' FROM ' + f'`{schema.table}`'
-        return 'SELECT 1'
+        projections = []
+        for column in schema.columns:
+            if column.name in column_names:
+                quoted = f'`{column.name}`'
+                if column.ch_type.base_name == 'String':
+                    if column.src_type.name == 'STRING':
+                        projections.append(quoted)
+                    elif column.src_type.name == 'BYTES':
+                        # TO_BASE64(NULL) is NULL, what we want.
+                        projections.append(f'TO_BASE64({quoted}) AS {quoted}')
+                    elif column.src_type.name.startswith('ARRAY'):
+                        projections.append(f'TO_JSON({quoted}) AS {quoted}')
+                    elif column.src_type.name == 'JSON':
+                        projections.append(f"IF({quoted} IS NULL, NULL, FORMAT('%t', {quoted})) AS {quoted}")
+                    elif column.src_type.name == 'RECORD':
+                        projections.append(f"IF({quoted} IS NULL, NULL, FORMAT('%t', {quoted})) AS {quoted}")
+                    elif column.src_type.name == 'GEOGRAPHY':
+                        # ST_ASTEXT(NULL) is NULL, what we want.
+                        projections.append(f'ST_ASTEXT({quoted}) AS {quoted}')
+                    else:
+                        # CAST(NULL AS STRING) is NULL, what we want.
+                        # https://cloud.google.com/bigquery/docs/reference/standard-sql/conversion_functions#cast_as_string
+                        projections.append(f'CAST({quoted} AS STRING) AS {quoted}')
+                elif column.ch_type.name == 'Array(Int64)':
+                    projections.append(f'TO_JSON({quoted}, stringify_wide_numbers=>FALSE) AS {quoted}')
+                elif column.ch_type.name == 'Array(Float64)':
+                    projections.append(f'TO_JSON({quoted}) AS {quoted}')
+                else:
+                    projections.append(quoted)
+        return 'SELECT ' + ', '.join(projections) + ' FROM ' + f"`{schema.scopes['dataset']}.{schema.scopes['table']}`"
 
     #
     # --- Query -----------------------------------------------------------------------------------
